@@ -35,7 +35,7 @@ def Busqueda(symbolo):
       elif c_element[1] != None:#Si tenemos una expresión
           return c_element[1]
       else:
-        return c_element[1]#Si es None
+        return symbolo#Si es None
   return symbolo
 
 def Redondear(expr):#Redondeamos la expresión.
